/*
 * Copyright (C) the libgit2 contributors. All rights reserved.
 *
 * This file is part of libgit2, distributed under the GNU GPL v2 with
 * a Linking Exception. For full terms see the included COPYING file.
 */

#ifndef CLI_cli_h__
#define CLI_cli_h__

#define PROGRAM_NAME "git2"

#include "git2_util.h"

#include "error.h"
#include "opt.h"
#include "opt_usage.h"
#include "sighandler.h"

#endif /* CLI_cli_h__ */
